@@ -4,59 +4,27 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Connection;
 
-use Doctrine\Common\Cache\ArrayCache;
-use Doctrine\Common\Cache\Cache;
-use Doctrine\Common\Cache\Psr6\DoctrineProvider;
 use Doctrine\DBAL\Cache\ArrayResult;
 use Doctrine\DBAL\Cache\QueryCacheProfile;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Driver;
 use PHPUnit\Framework\TestCase;
-use Psr\Cache\CacheItemPoolInterface;
 use Symfony\Component\Cache\Adapter\ArrayAdapter;
 
-use function class_exists;
-
 class CachedQueryTest extends TestCase
 {
     public function testCachedQuery(): void
     {
         $cache = new ArrayAdapter();
-        $this->assertCachedQueryIsExecutedOnceAndYieldsTheSameResult($cache, __FUNCTION__);
-        self::assertCount(1, $cache->getItem(__FUNCTION__)->get());
-    }
-
-    public function testCachedQueryLegacy(): void
-    {
-        if (! class_exists(ArrayCache::class)) {
-            self::markTestSkipped('This test requires the legacy ArrayCache class.');
-        }
-
-        $cache = new ArrayCache();
-        $this->assertCachedQueryIsExecutedOnceAndYieldsTheSameResult($cache, __FUNCTION__);
-
-        self::assertCount(1, $cache->fetch(__FUNCTION__));
-    }
-
-    public function testCachedQueryLegacyWrapped(): void
-    {
-        $cache  = new ArrayAdapter();
-        $legacy = DoctrineProvider::wrap($cache);
-        $this->assertCachedQueryIsExecutedOnceAndYieldsTheSameResult($legacy, __FUNCTION__);
-
-        self::assertCount(1, $cache->getItem(__FUNCTION__)->get());
-    }
-
-    /** @param CacheItemPoolInterface|Cache $cache */
-    private function assertCachedQueryIsExecutedOnceAndYieldsTheSameResult(object $cache, string $cacheKey): void
-    {
-        $data = [['foo' => 'bar']];
+        $data  = [['foo' => 'bar']];
 
         $connection = $this->createConnection(1, $data);
-        $qcp        = new QueryCacheProfile(0, $cacheKey, $cache);
+        $qcp        = new QueryCacheProfile(0, __FUNCTION__, $cache);
 
         self::assertSame($data, $connection->executeCacheQuery('SELECT 1', [], [], $qcp)->fetchAllAssociative());
         self::assertSame($data, $connection->executeCacheQuery('SELECT 1', [], [], $qcp)->fetchAllAssociative());
+
+        self::assertCount(1, $cache->getItem(__FUNCTION__)->get());
     }
 
     public function testCachedQueryWithChangedImplementationIsExecutedTwice(): void
