@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver\PDO\PgSQL;
 
 use Doctrine\DBAL\Driver as DriverInterface;
@@ -17,11 +19,11 @@ class DriverTest extends AbstractPostgreSQLDriverTestCase
     {
         parent::setUp();
 
-        if (isset($GLOBALS['db_type']) && $GLOBALS['db_driver'] === 'pdo_pgsql') {
+        if (isset($GLOBALS['db_driver']) && $GLOBALS['db_driver'] === 'pdo_pgsql') {
             return;
         }
 
-        $this->markTestSkipped('Test enabled only when using pdo_pgsql specific phpunit.xml');
+        self::markTestSkipped('Test enabled only when using pdo_pgsql specific phpunit.xml');
     }
 
     public function testConnectionDisablesPrepares(): void
