@@ -1,21 +1,33 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional;
 
 use Doctrine\DBAL\ArrayParameterType;
+use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\ParameterType;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Types;
+use PHPUnit\Framework\Attributes\DataProvider;
 use Throwable;
 
 use function array_change_key_case;
 
 use const CASE_LOWER;
 
+/** @psalm-import-type WrapperParameterType from Connection */
 class NamedParametersTest extends FunctionalTestCase
 {
-    /** @return iterable<int, array<int, mixed>> */
+    /**
+     * @psalm-return iterable<int, array{
+     *                   string,
+     *                   array<string, mixed>,
+     *                   array<string, WrapperParameterType>,
+     *                   list<array<string, mixed>>,
+     *               }>
+     */
     public static function ticketProvider(): iterable
     {
         return [
@@ -149,18 +161,18 @@ class NamedParametersTest extends FunctionalTestCase
 
     protected function setUp(): void
     {
-        if ($this->connection->getSchemaManager()->tablesExist('ddc1372_foobar')) {
+        if ($this->connection->createSchemaManager()->tableExists('ddc1372_foobar')) {
             return;
         }
 
         try {
             $table = new Table('ddc1372_foobar');
             $table->addColumn('id', Types::INTEGER);
-            $table->addColumn('foo', Types::STRING);
-            $table->addColumn('bar', Types::STRING);
+            $table->addColumn('foo', Types::STRING, ['length' => 1]);
+            $table->addColumn('bar', Types::STRING, ['length' => 1]);
             $table->setPrimaryKey(['id']);
 
-            $sm = $this->connection->getSchemaManager();
+            $sm = $this->connection->createSchemaManager();
             $sm->createTable($table);
 
             $this->connection->insert('ddc1372_foobar', [
@@ -199,12 +211,11 @@ class NamedParametersTest extends FunctionalTestCase
     }
 
     /**
-     * @param mixed[] $params
-     * @param int[]   $types
-     * @param int[]   $expected
-     *
-     * @dataProvider ticketProvider
+     * @param array<string, mixed>       $params
+     * @param list<array<string, mixed>> $expected
+     * @psalm-param array<string, WrapperParameterType> $types
      */
+    #[DataProvider('ticketProvider')]
     public function testTicket(string $query, array $params, array $types, array $expected): void
     {
         $data = $this->connection->fetchAllAssociative($query, $params, $types);
