@@ -1,16 +1,23 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Schema;
 
 use DateTime;
+use Doctrine\DBAL\DriverManager;
+use Doctrine\DBAL\Exception\DatabaseRequired;
 use Doctrine\DBAL\Platforms\AbstractMySQLPlatform;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\DBAL\Platforms\MariaDb1027Platform;
-use Doctrine\DBAL\Platforms\MariaDb1043Platform;
-use Doctrine\DBAL\Schema\Schema;
+use Doctrine\DBAL\Platforms\MariaDBPlatform;
 use Doctrine\DBAL\Schema\Table;
+use Doctrine\DBAL\Tests\Functional\Schema\MySQL\CustomType;
 use Doctrine\DBAL\Tests\Functional\Schema\MySQL\PointType;
+use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\BlobType;
+use Doctrine\DBAL\Types\FloatType;
+use Doctrine\DBAL\Types\JsonType;
+use Doctrine\DBAL\Types\SmallFloatType;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
 
@@ -40,40 +47,15 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableNew->setPrimaryKey(['bar_id', 'foo_id']);
 
         $diff = $this->schemaManager->createComparator()
-            ->diffTable($tableFetched, $tableNew);
-        self::assertNotFalse($diff);
+            ->compareTables($tableFetched, $tableNew);
 
         $this->schemaManager->alterTable($diff);
 
-        $table      = $this->schemaManager->introspectTable('switch_primary_key_columns');
-        $primaryKey = $table->getPrimaryKeyColumns();
+        $table = $this->schemaManager->introspectTable('switch_primary_key_columns');
 
-        self::assertCount(2, $primaryKey);
-        self::assertArrayHasKey('bar_id', $primaryKey);
-        self::assertArrayHasKey('foo_id', $primaryKey);
-    }
-
-    public function testDiffTableBug(): void
-    {
-        $schema = new Schema();
-        $table  = $schema->createTable('diffbug_routing_translations');
-        $table->addColumn('id', Types::INTEGER);
-        $table->addColumn('route', Types::STRING);
-        $table->addColumn('locale', Types::STRING);
-        $table->addColumn('attribute', Types::STRING);
-        $table->addColumn('localized_value', Types::STRING);
-        $table->addColumn('original_value', Types::STRING);
-        $table->setPrimaryKey(['id']);
-        $table->addUniqueIndex(['route', 'locale', 'attribute']);
-        $table->addIndex(['localized_value']); // this is much more selective than the unique index
-
-        $this->schemaManager->createTable($table);
-        $tableFetched = $this->schemaManager->introspectTable('diffbug_routing_translations');
-
-        $diff = $this->schemaManager->createComparator()
-            ->diffTable($tableFetched, $table);
-
-        self::assertFalse($diff, 'no changes expected.');
+        $primaryKey = $table->getPrimaryKey();
+        self::assertNotNull($primaryKey);
+        self::assertSame(['bar_id', 'foo_id'], $primaryKey->getColumns());
     }
 
     public function testFulltextIndex(): void
@@ -142,15 +124,14 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $diffTable->setPrimaryKey(['id']);
 
         $diff = $this->schemaManager->createComparator()
-            ->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+            ->compareTables($table, $diffTable);
 
         $this->schemaManager->alterTable($diff);
 
         $table = $this->schemaManager->introspectTable('alter_table_add_pk');
 
         self::assertFalse($table->hasIndex('idx_id'));
-        self::assertTrue($table->hasPrimaryKey());
+        self::assertNotNull($table->getPrimaryKey());
     }
 
     public function testDropPrimaryKeyWithAutoincrementColumn(): void
@@ -167,22 +148,21 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $diffTable->dropPrimaryKey();
 
         $diff = $this->schemaManager->createComparator()
-            ->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+            ->compareTables($table, $diffTable);
 
         $this->schemaManager->alterTable($diff);
 
         $table = $this->schemaManager->introspectTable('drop_primary_key');
 
-        self::assertFalse($table->hasPrimaryKey());
+        self::assertNull($table->getPrimaryKey());
         self::assertFalse($table->getColumn('id')->getAutoincrement());
     }
 
     public function testDoesNotPropagateDefaultValuesForUnsupportedColumnTypes(): void
     {
-        if ($this->connection->getDatabasePlatform() instanceof MariaDb1027Platform) {
+        if ($this->connection->getDatabasePlatform() instanceof MariaDBPlatform) {
             self::markTestSkipped(
-                'MariaDb102Platform supports default values for BLOB and TEXT columns and will propagate values',
+                'MariaDB supports default values for BLOB and TEXT columns and will propagate values',
             );
         }
 
@@ -203,9 +183,11 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertNull($onlineTable->getColumn('def_blob_null')->getDefault());
         self::assertFalse($onlineTable->getColumn('def_blob_null')->getNotnull());
 
-        $diff = $this->schemaManager->createComparator()
-            ->diffTable($table, $onlineTable);
-        self::assertFalse($diff);
+        self::assertTrue(
+            $this->schemaManager->createComparator()
+                ->compareTables($table, $onlineTable)
+                ->isEmpty(),
+        );
     }
 
     public function testColumnCharset(): void
@@ -236,8 +218,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $diffTable->getColumn('col_text')->setPlatformOption('charset', 'ascii');
 
         $diff = $this->schemaManager->createComparator()
-            ->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+            ->compareTables($table, $diffTable);
 
         $this->schemaManager->alterTable($diff);
 
@@ -253,18 +234,21 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
             ->setLength(100)
             ->setNotnull(true)
             ->setPlatformOption('charset', 'utf8');
+        $this->dropAndCreateTable($table);
 
         $diffTable = clone $table;
         $diffTable->getColumn('col_string')->setPlatformOption('charset', 'ascii');
 
-        $fromSchema = new Schema([$table]);
-        $toSchema   = new Schema([$diffTable]);
+        $diff = $this->schemaManager->createComparator()
+            ->compareTables($table, $diffTable);
 
-        $diff = $fromSchema->getMigrateToSql($toSchema, $this->connection->getDatabasePlatform());
-        self::assertContains(
-            'ALTER TABLE test_column_charset_change CHANGE col_string'
-                . ' col_string VARCHAR(100) CHARACTER SET ascii NOT NULL',
-            $diff,
+        $this->schemaManager->alterTable($diff);
+
+        self::assertEquals(
+            'ascii',
+            $this->schemaManager->introspectTable('test_column_charset_change')
+                ->getColumn('col_string')
+                ->getPlatformOption('charset'),
         );
     }
 
@@ -306,41 +290,40 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $platform       = $this->connection->getDatabasePlatform();
-        $offlineColumns = $table->getColumns();
-        $onlineColumns  = $this->schemaManager->listTableColumns($tableName);
+        $platform      = $this->connection->getDatabasePlatform();
+        $onlineColumns = $this->schemaManager->listTableColumns($tableName);
 
         self::assertSame(
-            $platform->getClobTypeDeclarationSQL($offlineColumns['col_tinytext']->toArray()),
+            $platform->getClobTypeDeclarationSQL($table->getColumn('col_tinytext')->toArray()),
             $platform->getClobTypeDeclarationSQL($onlineColumns['col_tinytext']->toArray()),
         );
         self::assertSame(
-            $platform->getClobTypeDeclarationSQL($offlineColumns['col_text']->toArray()),
+            $platform->getClobTypeDeclarationSQL($table->getColumn('col_text')->toArray()),
             $platform->getClobTypeDeclarationSQL($onlineColumns['col_text']->toArray()),
         );
         self::assertSame(
-            $platform->getClobTypeDeclarationSQL($offlineColumns['col_mediumtext']->toArray()),
+            $platform->getClobTypeDeclarationSQL($table->getColumn('col_mediumtext')->toArray()),
             $platform->getClobTypeDeclarationSQL($onlineColumns['col_mediumtext']->toArray()),
         );
         self::assertSame(
-            $platform->getClobTypeDeclarationSQL($offlineColumns['col_longtext']->toArray()),
+            $platform->getClobTypeDeclarationSQL($table->getColumn('col_longtext')->toArray()),
             $platform->getClobTypeDeclarationSQL($onlineColumns['col_longtext']->toArray()),
         );
 
         self::assertSame(
-            $platform->getBlobTypeDeclarationSQL($offlineColumns['col_tinyblob']->toArray()),
+            $platform->getBlobTypeDeclarationSQL($table->getColumn('col_tinyblob')->toArray()),
             $platform->getBlobTypeDeclarationSQL($onlineColumns['col_tinyblob']->toArray()),
         );
         self::assertSame(
-            $platform->getBlobTypeDeclarationSQL($offlineColumns['col_blob']->toArray()),
+            $platform->getBlobTypeDeclarationSQL($table->getColumn('col_blob')->toArray()),
             $platform->getBlobTypeDeclarationSQL($onlineColumns['col_blob']->toArray()),
         );
         self::assertSame(
-            $platform->getBlobTypeDeclarationSQL($offlineColumns['col_mediumblob']->toArray()),
+            $platform->getBlobTypeDeclarationSQL($table->getColumn('col_mediumblob')->toArray()),
             $platform->getBlobTypeDeclarationSQL($onlineColumns['col_mediumblob']->toArray()),
         );
         self::assertSame(
-            $platform->getBlobTypeDeclarationSQL($offlineColumns['col_longblob']->toArray()),
+            $platform->getBlobTypeDeclarationSQL($table->getColumn('col_longblob')->toArray()),
             $platform->getBlobTypeDeclarationSQL($onlineColumns['col_longblob']->toArray()),
         );
     }
@@ -354,8 +337,11 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $onlineTable = $this->schemaManager->introspectTable('list_guid_table_column');
 
-        self::assertFalse(
-            $this->schemaManager->createComparator()->diffTable($onlineTable, $offlineTable),
+        self::assertTrue(
+            $this->schemaManager
+                ->createComparator()
+                ->compareTables($onlineTable, $offlineTable)
+                ->isEmpty(),
             'No differences should be detected with the offline vs online schema.',
         );
     }
@@ -365,8 +351,16 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableName = 'test_list_decimal_columns';
         $table     = new Table($tableName);
 
-        $table->addColumn('col', Types::DECIMAL);
-        $table->addColumn('col_unsigned', Types::DECIMAL, ['unsigned' => true]);
+        $table->addColumn('col', Types::DECIMAL, [
+            'precision' => 10,
+            'scale' => 6,
+        ]);
+
+        $table->addColumn('col_unsigned', Types::DECIMAL, [
+            'precision' => 10,
+            'scale' => 6,
+            'unsigned' => true,
+        ]);
 
         $this->dropAndCreateTable($table);
 
@@ -378,22 +372,22 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertTrue($columns['col_unsigned']->getUnsigned());
     }
 
-    public function testListFloatTypeColumns(): void
+    public function testListUnsignedFloatTypeColumns(): void
     {
-        $tableName = 'test_list_float_columns';
+        $tableName = 'test_unsigned_float_columns';
         $table     = new Table($tableName);
 
-        $table->addColumn('col', Types::FLOAT);
         $table->addColumn('col_unsigned', Types::FLOAT, ['unsigned' => true]);
+        $table->addColumn('col_smallfloat_unsigned', Types::SMALLFLOAT, ['unsigned' => true]);
 
         $this->dropAndCreateTable($table);
 
         $columns = $this->schemaManager->listTableColumns($tableName);
 
-        self::assertArrayHasKey('col', $columns);
-        self::assertArrayHasKey('col_unsigned', $columns);
-        self::assertFalse($columns['col']->getUnsigned());
+        self::assertInstanceOf(FloatType::class, $columns['col_unsigned']->getType());
+        self::assertInstanceOf(SmallFloatType::class, $columns['col_smallfloat_unsigned']->getType());
         self::assertTrue($columns['col_unsigned']->getUnsigned());
+        self::assertTrue($columns['col_smallfloat_unsigned']->getUnsigned());
     }
 
     public function testJsonColumnType(): void
@@ -402,14 +396,9 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $table->addColumn('col_json', Types::JSON);
         $this->dropAndCreateTable($table);
 
-        // Remove the comment from the column to ensure the type is detected correctly from the check constraints.
-        if ($this->connection->getDatabasePlatform() instanceof MariaDb1043Platform) {
-            $this->connection->executeStatement('ALTER TABLE test_mysql_json CHANGE COLUMN col_json col_json JSON');
-        }
-
         $columns = $this->schemaManager->listTableColumns('test_mysql_json');
 
-        self::assertSame(Types::JSON, $columns['col_json']->getType()->getName());
+        self::assertInstanceOf(JsonType::class, $columns['col_json']->getType());
     }
 
     public function testColumnDefaultCurrentTimestamp(): void
@@ -433,8 +422,12 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertSame($currentTimeStampSql, $onlineTable->getColumn('col_datetime')->getDefault());
         self::assertSame($currentTimeStampSql, $onlineTable->getColumn('col_datetime_nullable')->getDefault());
 
-        $diff = $this->schemaManager->createComparator()->diffTable($table, $onlineTable);
-        self::assertFalse($diff, 'Tables should be identical with column defaults.');
+        self::assertTrue(
+            $this->schemaManager
+                ->createComparator()
+                ->compareTables($table, $onlineTable)
+                ->isEmpty(),
+        );
     }
 
     public function testColumnDefaultsAreValid(): void
@@ -446,7 +439,10 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $table->addColumn('col_datetime_null', Types::DATETIME_MUTABLE, ['notnull' => false, 'default' => null]);
         $table->addColumn('col_int', Types::INTEGER, ['default' => 1]);
         $table->addColumn('col_neg_int', Types::INTEGER, ['default' => -1]);
-        $table->addColumn('col_string', Types::STRING, ['default' => 'A']);
+        $table->addColumn('col_string', Types::STRING, [
+            'length' => 1,
+            'default' => 'A',
+        ]);
         $table->addColumn('col_decimal', Types::DECIMAL, ['scale' => 3, 'precision' => 6, 'default' => -2.3]);
         $table->addColumn('col_date', Types::DATE_MUTABLE, ['default' => '2012-12-12']);
 
@@ -483,8 +479,8 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
      */
     public function testColumnDefaultValuesCurrentTimeAndDate(): void
     {
-        if (! $this->connection->getDatabasePlatform() instanceof MariaDb1027Platform) {
-            self::markTestSkipped('Only relevant for MariaDb102Platform.');
+        if (! $this->connection->getDatabasePlatform() instanceof MariaDBPlatform) {
+            self::markTestSkipped('Only relevant for MariaDB.');
         }
 
         $platform = $this->connection->getDatabasePlatform();
@@ -507,8 +503,12 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertSame($currentDateSql, $onlineTable->getColumn('col_date')->getDefault());
         self::assertSame($currentTimeSql, $onlineTable->getColumn('col_time')->getDefault());
 
-        $diff = $this->schemaManager->createComparator()->diffTable($table, $onlineTable);
-        self::assertFalse($diff, 'Tables should be identical with column defauts time and date.');
+        self::assertTrue(
+            $this->schemaManager
+                ->createComparator()
+                ->compareTables($table, $onlineTable)
+                ->isEmpty(),
+        );
     }
 
     public function testEnsureTableOptionsAreReflectedInMetadata(): void
@@ -561,15 +561,55 @@ SQL;
         $doctrineTypes = array_keys(Type::getTypesMap());
 
         foreach ($doctrineTypes as $type) {
-            $table->addColumn('col_' . $type, $type);
+            $table->addColumn('col_' . $type, $type, ['length' => 8, 'precision' => 8, 'scale' => 2]);
         }
 
         $this->dropAndCreateTable($table);
 
         $onlineTable = $this->schemaManager->introspectTable('test_column_introspection');
 
-        $diff = $this->schemaManager->createComparator()->diffTable($table, $onlineTable);
+        $diff = $this->schemaManager->createComparator()->compareTables($table, $onlineTable);
 
-        self::assertFalse($diff, 'Tables should be identical.');
+        self::assertTrue($diff->isEmpty(), 'Tables should be identical.');
+    }
+
+    public function testListTableColumnsThrowsDatabaseRequired(): void
+    {
+        $params = TestUtil::getConnectionParams();
+        unset($params['dbname']);
+
+        $connection    = DriverManager::getConnection($params);
+        $schemaManager = $connection->createSchemaManager();
+
+        $this->expectException(DatabaseRequired::class);
+
+        $schemaManager->listTableColumns('users');
+    }
+
+    public function testSchemaDiffWithCustomColumnTypeWhileDatabaseTypeDiffers(): void
+    {
+        Type::addType('custom_type', CustomType::class);
+
+        $metadataTable = new Table('table_with_custom_type');
+        $metadataTable->addColumn('col1', 'custom_type');
+
+        self::assertSame(
+            ['CREATE TABLE table_with_custom_type (col1 INT NOT NULL)'],
+            $this->connection->getDatabasePlatform()->getCreateTableSQL($metadataTable),
+        );
+
+        $this->connection->executeStatement('DROP TABLE IF EXISTS table_with_custom_type');
+
+        $this->connection->executeStatement('CREATE TABLE table_with_custom_type (col1 VARCHAR(255) NOT NULL)');
+        $onlineTable = $this->schemaManager->introspectTable('table_with_custom_type');
+
+        $comparator = $this->schemaManager->createComparator();
+        $tablesDiff = $comparator->compareTables($onlineTable, $metadataTable);
+
+        self::assertSame(
+            ['ALTER TABLE table_with_custom_type CHANGE col1 col1 INT NOT NULL'],
+            $this->connection->getDatabasePlatform()->getAlterTableSQL($tablesDiff),
+            ' The column should be changed from VARCAHR TO INT',
+        );
     }
 }
