@@ -1,16 +1,19 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Schema;
 
 use Doctrine\DBAL\Exception\DatabaseObjectNotFoundException;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\OraclePlatform;
-use Doctrine\DBAL\Schema\AbstractSchemaManager;
-use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\Index;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\BinaryType;
+use Doctrine\DBAL\Types\DateTimeType;
+use Doctrine\DBAL\Types\DateTimeTzType;
+use Doctrine\DBAL\Types\DateType;
 use Doctrine\DBAL\Types\Types;
 
 use function array_map;
@@ -32,19 +35,14 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertSame($expectedLength, $column->getLength());
     }
 
-    /**
-     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
-     *
-     * @dataProvider \Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils::comparatorProvider
-     */
-    public function testAlterTableColumnNotNull(callable $comparatorFactory): void
+    public function testAlterTableColumnNotNull(): void
     {
         $tableName = 'list_table_column_notnull';
         $table     = new Table($tableName);
 
         $table->addColumn('id', Types::INTEGER);
         $table->addColumn('foo', Types::INTEGER);
-        $table->addColumn('bar', Types::STRING);
+        $table->addColumn('bar', Types::STRING, ['length' => 32]);
         $table->setPrimaryKey(['id']);
 
         $this->dropAndCreateTable($table);
@@ -56,11 +54,11 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertTrue($columns['bar']->getNotnull());
 
         $diffTable = clone $table;
-        $diffTable->changeColumn('foo', ['notnull' => false]);
-        $diffTable->changeColumn('bar', ['length' => 1024]);
+        $diffTable->modifyColumn('foo', ['notnull' => false]);
+        $diffTable->modifyColumn('bar', ['length' => 1024]);
 
-        $diff = $comparatorFactory($this->schemaManager)->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+        $diff = $this->schemaManager->createComparator()
+            ->compareTables($table, $diffTable);
 
         $this->schemaManager->alterTable($diff);
 
@@ -78,10 +76,10 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $offlinePrimaryTable->addColumn(
             '"Id"',
             Types::INTEGER,
-            ['autoincrement' => true, 'comment' => 'Explicit casing.'],
+            ['autoincrement' => true],
         );
-        $offlinePrimaryTable->addColumn('select', Types::INTEGER, ['comment' => 'Reserved keyword.']);
-        $offlinePrimaryTable->addColumn('foo', Types::INTEGER, ['comment' => 'Implicit uppercasing.']);
+        $offlinePrimaryTable->addColumn('select', Types::INTEGER);
+        $offlinePrimaryTable->addColumn('foo', Types::INTEGER);
         $offlinePrimaryTable->addColumn('BAR', Types::INTEGER);
         $offlinePrimaryTable->addColumn('"BAZ"', Types::INTEGER);
         $offlinePrimaryTable->addIndex(['select'], 'from');
@@ -120,12 +118,10 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         self::assertTrue($onlinePrimaryTable->hasColumn('"Id"'));
         self::assertSame('"Id"', $onlinePrimaryTable->getColumn('"Id"')->getQuotedName($platform));
-        self::assertTrue($onlinePrimaryTable->hasPrimaryKey());
 
-        $primaryKey = $onlinePrimaryTable->getPrimaryKey();
-
-        self::assertNotNull($primaryKey);
-        self::assertSame(['"Id"'], $primaryKey->getQuotedColumns($platform));
+        $onlinePrimaryTablePrimaryKey = $onlinePrimaryTable->getPrimaryKey();
+        self::assertNotNull($onlinePrimaryTablePrimaryKey);
+        self::assertSame(['"Id"'], $onlinePrimaryTablePrimaryKey->getQuotedColumns($platform));
 
         self::assertTrue($onlinePrimaryTable->hasColumn('select'));
         self::assertSame('"select"', $onlinePrimaryTable->getColumn('select')->getQuotedName($platform));
@@ -158,12 +154,10 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         // Foreign table assertions
         self::assertTrue($onlineForeignTable->hasColumn('id'));
         self::assertSame('ID', $onlineForeignTable->getColumn('id')->getQuotedName($platform));
-        self::assertTrue($onlineForeignTable->hasPrimaryKey());
 
-        $primaryKey = $onlineForeignTable->getPrimaryKey();
-
-        self::assertNotNull($primaryKey);
-        self::assertSame(['ID'], $primaryKey->getQuotedColumns($platform));
+        $onlineForeignTablePrimaryKey = $onlineForeignTable->getPrimaryKey();
+        self::assertNotNull($onlineForeignTablePrimaryKey);
+        self::assertSame(['ID'], $onlineForeignTablePrimaryKey->getQuotedColumns($platform));
 
         self::assertTrue($onlineForeignTable->hasColumn('"Fk"'));
         self::assertSame('"Fk"', $onlineForeignTable->getColumn('"Fk"')->getQuotedName($platform));
@@ -193,14 +187,14 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $this->dropAndCreateTable($table);
 
         $otherTable = new Table($table->getName());
-        $otherTable->addColumn('id', Types::STRING);
+        $otherTable->addColumn('id', Types::STRING, ['length' => 32]);
 
         $connection    = TestUtil::getPrivilegedConnection();
-        $schemaManager = $connection->getSchemaManager();
+        $schemaManager = $connection->createSchemaManager();
 
         try {
             $schemaManager->dropTable($otherTable->getName());
-        } catch (DatabaseObjectNotFoundException $e) {
+        } catch (DatabaseObjectNotFoundException) {
         }
 
         $schemaManager->createTable($otherTable);
@@ -242,9 +236,9 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $columns = $this->schemaManager->listTableColumns('tbl_date');
 
-        self::assertSame(Types::DATE_MUTABLE, $columns['col_date']->getType()->getName());
-        self::assertSame(Types::DATETIME_MUTABLE, $columns['col_datetime']->getType()->getName());
-        self::assertSame(Types::DATETIMETZ_MUTABLE, $columns['col_datetimetz']->getType()->getName());
+        self::assertInstanceOf(DateType::class, $columns['col_date']->getType());
+        self::assertInstanceOf(DateTimeType::class, $columns['col_datetime']->getType());
+        self::assertInstanceOf(DateTimeTzType::class, $columns['col_datetimetz']->getType());
     }
 
     public function testCreateAndListSequences(): void
@@ -258,18 +252,18 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
     {
         $table = new Table('"tester"');
         $table->addColumn('"id"', Types::INTEGER);
-        $table->addColumn('"name"', Types::STRING);
+        $table->addColumn('"name"', Types::STRING, ['length' => 32]);
 
         $this->dropAndCreateTable($table);
 
         $schemaManager = $this->connection->createSchemaManager();
 
-        $fromSchema = $schemaManager->introspectSchema();
-        $toSchema   = clone $fromSchema;
+        $oldSchema = $schemaManager->introspectSchema();
+        $newSchema = clone $oldSchema;
 
-        $toSchema->getTable('"tester"')->dropColumn('"name"');
+        $newSchema->getTable('"tester"')->dropColumn('"name"');
         $diff = $schemaManager->createComparator()
-            ->compareSchemas($fromSchema, $toSchema);
+            ->compareSchemas($oldSchema, $newSchema);
 
         $schemaManager->alterSchema($diff);
 
