@@ -1,33 +1,27 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Schema;
 
-use Doctrine\DBAL\Driver\ServerInfoAwareConnection;
-use Doctrine\DBAL\Exception\DatabaseObjectNotFoundException;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\PostgreSQL120Platform;
 use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
-use Doctrine\DBAL\Schema\AbstractSchemaManager;
-use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
-use Doctrine\DBAL\Schema\PostgreSQLSchemaManager;
 use Doctrine\DBAL\Schema\Schema;
 use Doctrine\DBAL\Schema\Table;
-use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Schema\View;
 use Doctrine\DBAL\Types\BlobType;
 use Doctrine\DBAL\Types\DecimalType;
 use Doctrine\DBAL\Types\IntegerType;
+use Doctrine\DBAL\Types\JsonType;
 use Doctrine\DBAL\Types\TextType;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
-use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 use function array_map;
-use function array_merge;
 use function array_pop;
-use function array_unshift;
-use function assert;
 use function count;
 use function sprintf;
 use function strtolower;
@@ -35,31 +29,14 @@ use function version_compare;
 
 class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function supportsPlatform(AbstractPlatform $platform): bool
     {
         return $platform instanceof PostgreSQLPlatform;
     }
 
-    public function testGetSearchPath(): void
-    {
-        $expected = ['public'];
-
-        $params = $this->connection->getParams();
-
-        if (isset($params['user'])) {
-            array_unshift($expected, $params['user']);
-        }
-
-        self::assertEquals($expected, $this->schemaManager->getSchemaSearchPaths());
-    }
-
     public function testGetSchemaNames(): void
     {
-        assert($this->schemaManager instanceof PostgreSQLSchemaManager);
-
-        $names = $this->schemaManager->getSchemaNames();
+        $names = $this->schemaManager->listSchemaNames();
 
         self::assertContains('public', $names, 'The public schema should be found.');
     }
@@ -72,13 +49,13 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $createTableSQL = 'CREATE TABLE domain_type_test (id INT PRIMARY KEY, value MyMoney)';
         $this->connection->executeStatement($createTableSQL);
 
-        $table = $this->connection->getSchemaManager()->introspectTable('domain_type_test');
+        $table = $this->connection->createSchemaManager()->introspectTable('domain_type_test');
         self::assertInstanceOf(DecimalType::class, $table->getColumn('value')->getType());
 
         Type::addType('MyMoney', MoneyType::class);
         $this->connection->getDatabasePlatform()->registerDoctrineTypeMapping('MyMoney', 'MyMoney');
 
-        $table = $this->connection->getSchemaManager()->introspectTable('domain_type_test');
+        $table = $this->connection->createSchemaManager()->introspectTable('domain_type_test');
         self::assertInstanceOf(MoneyType::class, $table->getColumn('value')->getType());
     }
 
@@ -93,19 +70,8 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertTrue($autoincTable->getColumn('id')->getAutoincrement());
     }
 
-    /**
-     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
-     *
-     * @dataProvider \Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils::comparatorProvider
-     */
-    public function testAlterTableAutoIncrementAdd(callable $comparatorFactory): void
+    public function testAlterTableAutoIncrementAdd(): void
     {
-        // see https://github.com/doctrine/dbal/issues/4745
-        try {
-            $this->schemaManager->dropSequence('autoinc_table_add_id_seq');
-        } catch (DatabaseObjectNotFoundException $e) {
-        }
-
         $tableFrom = new Table('autoinc_table_add');
         $tableFrom->addColumn('id', Types::INTEGER);
         $this->dropAndCreateTable($tableFrom);
@@ -117,27 +83,18 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $column->setAutoincrement(true);
 
         $platform = $this->connection->getDatabasePlatform();
-        $diff     = $comparatorFactory($this->schemaManager)->diffTable($tableFrom, $tableTo);
-        self::assertNotFalse($diff);
+        $diff     = $this->schemaManager->createComparator()
+            ->compareTables($tableFrom, $tableTo);
 
         $sql = $platform->getAlterTableSQL($diff);
-        self::assertEquals([
-            'CREATE SEQUENCE autoinc_table_add_id_seq',
-            "SELECT setval('autoinc_table_add_id_seq', (SELECT MAX(id) FROM autoinc_table_add))",
-            "ALTER TABLE autoinc_table_add ALTER id SET DEFAULT nextval('autoinc_table_add_id_seq')",
-        ], $sql);
+        self::assertEquals(['ALTER TABLE autoinc_table_add ALTER id ADD GENERATED BY DEFAULT AS IDENTITY'], $sql);
 
         $this->schemaManager->alterTable($diff);
         $tableFinal = $this->schemaManager->introspectTable('autoinc_table_add');
         self::assertTrue($tableFinal->getColumn('id')->getAutoincrement());
     }
 
-    /**
-     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
-     *
-     * @dataProvider \Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils::comparatorProvider
-     */
-    public function testAlterTableAutoIncrementDrop(callable $comparatorFactory): void
+    public function testAlterTableAutoIncrementDrop(): void
     {
         $tableFrom = new Table('autoinc_table_drop');
         $column    = $tableFrom->addColumn('id', Types::INTEGER);
@@ -150,11 +107,11 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableTo->addColumn('id', Types::INTEGER);
 
         $platform = $this->connection->getDatabasePlatform();
-        $diff     = $comparatorFactory($this->schemaManager)->diffTable($tableFrom, $tableTo);
-        self::assertNotFalse($diff);
+        $diff     = $this->schemaManager->createComparator()
+            ->compareTables($tableFrom, $tableTo);
 
         self::assertEquals(
-            ['ALTER TABLE autoinc_table_drop ALTER id DROP DEFAULT'],
+            ['ALTER TABLE autoinc_table_drop ALTER id DROP IDENTITY'],
             $platform->getAlterTableSQL($diff),
         );
 
@@ -176,7 +133,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $column            = $nestedSchemaTable->addColumn('id', Types::INTEGER);
         $column->setAutoincrement(true);
         $nestedSchemaTable->setPrimaryKey(['id']);
-        $nestedSchemaTable->addForeignKeyConstraint($nestedRelatedTable, ['id'], ['id']);
+        $nestedSchemaTable->addForeignKeyConstraint($nestedRelatedTable->getName(), ['id'], ['id']);
 
         $this->schemaManager->createTable($nestedRelatedTable);
         $this->schemaManager->createTable($nestedSchemaTable);
@@ -191,13 +148,13 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertTrue($nestedSchemaTable->hasColumn('id'));
 
         $primaryKey = $nestedSchemaTable->getPrimaryKey();
-
         self::assertNotNull($primaryKey);
         self::assertEquals(['id'], $primaryKey->getColumns());
 
         $relatedFks = $nestedSchemaTable->getForeignKeys();
         self::assertCount(1, $relatedFks);
         $relatedFk = array_pop($relatedFks);
+        self::assertNotNull($relatedFk);
         self::assertEquals('nested.schemarelated', $relatedFk->getForeignTableName());
     }
 
@@ -214,17 +171,17 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $anotherSchemaTable->addColumn('email', Types::TEXT);
         $this->schemaManager->createTable($anotherSchemaTable);
 
-        $table = $this->schemaManager->listTableDetails('table');
-        $this->assertCount(2, $table->getColumns());
-        $this->assertTrue($table->hasColumn('id'));
-        $this->assertInstanceOf(IntegerType::class, $table->getColumn('id')->getType());
-        $this->assertTrue($table->hasColumn('name'));
+        $table = $this->schemaManager->introspectTable('table');
+        self::assertCount(2, $table->getColumns());
+        self::assertTrue($table->hasColumn('id'));
+        self::assertInstanceOf(IntegerType::class, $table->getColumn('id')->getType());
+        self::assertTrue($table->hasColumn('name'));
 
-        $anotherSchemaTable = $this->schemaManager->listTableDetails('another.table');
-        $this->assertCount(2, $anotherSchemaTable->getColumns());
-        $this->assertTrue($anotherSchemaTable->hasColumn('id'));
-        $this->assertInstanceOf(TextType::class, $anotherSchemaTable->getColumn('id')->getType());
-        $this->assertTrue($anotherSchemaTable->hasColumn('email'));
+        $anotherSchemaTable = $this->schemaManager->introspectTable('another.table');
+        self::assertCount(2, $anotherSchemaTable->getColumns());
+        self::assertTrue($anotherSchemaTable->hasColumn('id'));
+        self::assertInstanceOf(TextType::class, $anotherSchemaTable->getColumn('id')->getType());
+        self::assertTrue($anotherSchemaTable->hasColumn('email'));
     }
 
     public function testReturnQuotedAssets(): void
@@ -245,6 +202,8 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
             [
                 'CREATE TABLE dbal91_something (id INT NOT NULL, "table" INT DEFAULT NULL, PRIMARY KEY(id))',
                 'CREATE INDEX IDX_A9401304ECA7352B ON dbal91_something ("table")',
+                'ALTER TABLE dbal91_something ADD CONSTRAINT something_input FOREIGN KEY ("table")'
+                    . ' REFERENCES dbal91_something (id) ON UPDATE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE',
             ],
             $this->connection->getDatabasePlatform()->getCreateTableSQL($table),
         );
@@ -255,14 +214,14 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $fkOptions   = ['SET NULL', 'SET DEFAULT', 'NO ACTION', 'CASCADE', 'RESTRICT'];
         $foreignKeys = [];
         $fkTable     = $this->getTestTable('test_create_fk1');
-        for ($i = 0; $i < count($fkOptions); $i++) {
+        foreach ($fkOptions as $i => $fkOption) {
             $fkTable->addColumn('foreign_key_test' . $i, Types::INTEGER);
             $foreignKeys[] = new ForeignKeyConstraint(
                 ['foreign_key_test' . $i],
                 'test_create_fk2',
                 ['id'],
                 'foreign_key_test' . $i . '_fk',
-                ['onDelete' => $fkOptions[$i]],
+                ['onDelete' => $fkOption],
             );
         }
 
@@ -315,12 +274,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertSame('{"key": "value with a single quote \' in string value"}', $columns['foo']->getDefault());
     }
 
-    /**
-     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
-     *
-     * @dataProvider \Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils::comparatorProvider
-     */
-    public function testBooleanDefault(callable $comparatorFactory): void
+    public function testBooleanDefault(): void
     {
         $table = new Table('ddc2843_bools');
         $table->addColumn('id', Types::INTEGER);
@@ -330,19 +284,15 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $databaseTable = $this->schemaManager->introspectTable($table->getName());
 
-        $diff = $comparatorFactory($this->schemaManager)->diffTable($table, $databaseTable);
-
-        self::assertFalse($diff);
+        self::assertTrue(
+            $this->schemaManager->createComparator()
+                ->compareTables($table, $databaseTable)
+                ->isEmpty(),
+        );
     }
 
-    /**
-     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
-     *
-     * @dataProvider \Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils::comparatorProvider
-     */
-    public function testGeneratedColumn(callable $comparatorFactory): void
+    public function testGeneratedColumn(): void
     {
-        $wrappedConnection = $this->connection->getWrappedConnection();
         if (! $this->connection->getDatabasePlatform() instanceof PostgreSQL120Platform) {
              self::markTestSkipped('Generated columns are not supported in Postgres 11 and earlier');
         }
@@ -359,9 +309,11 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $databaseTable = $this->schemaManager->introspectTable($table->getName());
 
-        $diff = $comparatorFactory($this->schemaManager)->diffTable($table, $databaseTable);
-
-        self::assertFalse($diff);
+        self::assertTrue(
+            $this->schemaManager->createComparator()
+                ->compareTables($table, $databaseTable)
+                ->isEmpty(),
+        );
     }
 
     /**
@@ -438,7 +390,6 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $foundTable = false;
         foreach ($tables as $table) {
-            self::assertInstanceOf(Table::class, $table, 'No Table instance was found in tables array.');
             if (strtolower($table->getName()) !== 'list_tables_excludes_views_test_view') {
                 continue;
             }
@@ -461,9 +412,11 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $onlineTable = $this->schemaManager->introspectTable('person');
 
-        $comparator = new Comparator();
-
-        self::assertFalse($comparator->diffTable($offlineTable, $onlineTable));
+        self::assertTrue(
+            $this->schemaManager->createComparator()
+                ->compareTables($offlineTable, $onlineTable)
+                ->isEmpty(),
+        );
         self::assertTrue($onlineTable->hasIndex('simple_partial_index'));
         self::assertTrue($onlineTable->getIndex('simple_partial_index')->hasOption('where'));
         self::assertSame('(id IS NULL)', $onlineTable->getIndex('simple_partial_index')->getOption('where'));
@@ -477,40 +430,8 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $columns = $this->schemaManager->listTableColumns('test_jsonb');
 
-        self::assertSame(Types::JSON, $columns['foo']->getType()->getName());
-        self::assertTrue(true, $columns['foo']->getPlatformOption('jsonb'));
-    }
-
-    public function testItTriggersADeprecationWhenAttemptingToUseJsonbWithATypeNotExtendingJsonType(): void
-    {
-        $backedUpType = Type::getType(Types::JSON);
-        try {
-            Type::getTypeRegistry()->override(Types::JSON, new class extends Type {
-                /**
-                 * {@inheritDoc}
-                 */
-                public function getSQLDeclaration(array $column, AbstractPlatform $platform): string
-                {
-                    return $platform->getJsonTypeDeclarationSQL($column);
-                }
-
-                public function getName(): string
-                {
-                    return Types::JSON;
-                }
-            });
-            $table = new Table('test_jsonb');
-            $table->addColumn('foo', Types::JSON)->setPlatformOption('jsonb', true);
-            $this->dropAndCreateTable($table);
-
-            $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/5049');
-            $columns = $this->schemaManager->listTableColumns('test_jsonb');
-
-            self::assertSame(Types::JSON, $columns['foo']->getType()->getName());
-            self::assertTrue(true, $columns['foo']->getPlatformOption('jsonb'));
-        } finally {
-            Type::getTypeRegistry()->override(Types::JSON, $backedUpType);
-        }
+        self::assertInstanceOf(JsonType::class, $columns['foo']->getType());
+        self::assertTrue($columns['foo']->getPlatformOption('jsonb'));
     }
 
     public function testListNegativeColumnDefaultValue(): void
@@ -520,7 +441,12 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $table->addColumn('col_integer', Types::INTEGER, ['default' => -1]);
         $table->addColumn('col_bigint', Types::BIGINT, ['default' => -1]);
         $table->addColumn('col_float', Types::FLOAT, ['default' => -1.1]);
-        $table->addColumn('col_decimal', Types::DECIMAL, ['default' => -1.1]);
+        $table->addColumn('col_smallfloat', Types::SMALLFLOAT, ['default' => -1.1]);
+        $table->addColumn('col_decimal', Types::DECIMAL, [
+            'precision' => 2,
+            'scale' => 1,
+            'default' => -1.1,
+        ]);
         $table->addColumn('col_string', Types::STRING, ['default' => '(-1)']);
 
         $this->dropAndCreateTable($table);
@@ -531,6 +457,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertEquals(-1, $columns['col_integer']->getDefault());
         self::assertEquals(-1, $columns['col_bigint']->getDefault());
         self::assertEquals(-1.1, $columns['col_float']->getDefault());
+        self::assertEquals(-1.1, $columns['col_smallfloat']->getDefault());
         self::assertEquals(-1.1, $columns['col_decimal']->getDefault());
         self::assertEquals('(-1)', $columns['col_string']->getDefault());
     }
@@ -544,7 +471,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         ];
     }
 
-    /** @dataProvider serialTypes */
+    #[DataProvider('serialTypes')]
     public function testAutoIncrementCreatesSerialDataTypesWithoutADefaultValue(string $type): void
     {
         $tableName = 'test_serial_type_' . $type;
@@ -559,7 +486,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertNull($columns['id']->getDefault());
     }
 
-    /** @dataProvider serialTypes */
+    #[DataProvider('serialTypes')]
     public function testAutoIncrementCreatesSerialDataTypesWithoutADefaultValueEvenWhenDefaultIsSet(string $type): void
     {
         $tableName = 'test_serial_type_with_default_' . $type;
@@ -574,30 +501,24 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertNull($columns['id']->getDefault());
     }
 
-    /**
-     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
-     *
-     * @dataProvider autoIncrementTypeMigrations
-     */
-    public function testAlterTableAutoIncrementIntToBigInt(
-        callable $comparatorFactory,
-        string $from,
-        string $to,
-        string $expected
-    ): void {
-        $tableFrom = new Table('autoinc_type_modification');
-        $column    = $tableFrom->addColumn('id', $from);
+    #[DataProvider('autoIncrementTypeMigrations')]
+    public function testAlterTableAutoIncrementIntToBigInt(string $from, string $to, string $expected): void
+    {
+        $table  = new Table('autoinc_type_modification');
+        $column = $table->addColumn('id', $from);
         $column->setAutoincrement(true);
-        $this->dropAndCreateTable($tableFrom);
-        $tableFrom = $this->schemaManager->introspectTable('autoinc_type_modification');
-        self::assertTrue($tableFrom->getColumn('id')->getAutoincrement());
+        $this->dropAndCreateTable($table);
 
-        $tableTo = new Table('autoinc_type_modification');
-        $column  = $tableTo->addColumn('id', $to);
+        $oldTable = $this->schemaManager->introspectTable('autoinc_type_modification');
+        self::assertTrue($oldTable->getColumn('id')->getAutoincrement());
+
+        $newTable = new Table('autoinc_type_modification');
+        $column   = $newTable->addColumn('id', $to);
         $column->setAutoincrement(true);
 
-        $diff = $comparatorFactory($this->schemaManager)->diffTable($tableFrom, $tableTo);
-        self::assertInstanceOf(TableDiff::class, $diff);
+        $diff = $this->schemaManager->createComparator()
+            ->compareTables($oldTable, $newTable);
+
         self::assertSame(
             ['ALTER TABLE autoinc_type_modification ALTER id TYPE ' . $expected],
             $this->connection->getDatabasePlatform()->getAlterTableSQL($diff),
@@ -610,16 +531,14 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
     public function testListTableColumnsOidConflictWithNonTableObject(): void
     {
-        $wrappedConnection = $this->connection->getWrappedConnection();
-        assert($wrappedConnection instanceof ServerInfoAwareConnection);
-        if (version_compare($wrappedConnection->getServerVersion(), '12.0', '<')) {
+        if (version_compare($this->connection->getServerVersion(), '12.0', '<')) {
             self::markTestSkipped('Manually setting the Oid is not supported in Postgres 11 and earlier');
         }
 
         $table = 'test_list_table_columns_oid_conflicts';
         $this->connection->executeStatement(sprintf('CREATE TABLE IF NOT EXISTS %s(id INT NOT NULL)', $table));
         $beforeColumns = $this->schemaManager->listTableColumns($table);
-        $this->assertArrayHasKey('id', $beforeColumns);
+        self::assertArrayHasKey('id', $beforeColumns);
 
         $this->connection->executeStatement('CREATE EXTENSION IF NOT EXISTS pg_prewarm');
         $originalTableOid = $this->connection->fetchOne(
@@ -668,22 +587,16 @@ SQL;
         $this->connection->executeStatement(sprintf('DROP TABLE IF EXISTS %s', $table));
         $this->connection->executeStatement('DROP EXTENSION IF EXISTS pg_prewarm');
 
-        $this->assertArrayHasKey('id', $afterColumns);
+        self::assertArrayHasKey('id', $afterColumns);
     }
 
     /** @return iterable<mixed[]> */
     public static function autoIncrementTypeMigrations(): iterable
     {
-        foreach (ComparatorTestUtils::comparatorProvider() as $comparatorArguments) {
-            foreach (
-                [
-                    'int -> bigint' => ['integer', 'bigint', 'BIGINT'],
-                    'bigint -> int' => ['bigint', 'integer', 'INT'],
-                ] as $testArguments
-            ) {
-                yield array_merge($comparatorArguments, $testArguments);
-            }
-        }
+        return [
+            'int->bigint' => ['integer', 'bigint', 'BIGINT'],
+            'bigint->int' => ['bigint', 'integer', 'INT'],
+        ];
     }
 }
 
@@ -692,15 +605,7 @@ class MoneyType extends Type
     /**
      * {@inheritDoc}
      */
-    public function getName()
-    {
-        return 'MyMoney';
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function getSQLDeclaration(array $column, AbstractPlatform $platform)
+    public function getSQLDeclaration(array $column, AbstractPlatform $platform): string
     {
         return 'MyMoney';
     }
