@@ -1,11 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests;
 
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Exception\DatabaseObjectNotFoundException;
 use Doctrine\DBAL\Schema\Table;
+use PHPUnit\Framework\Attributes\After;
+use PHPUnit\Framework\Attributes\Before;
 use PHPUnit\Framework\TestCase;
 
 abstract class FunctionalTestCase extends TestCase
@@ -33,7 +37,7 @@ abstract class FunctionalTestCase extends TestCase
         $this->isConnectionReusable = false;
     }
 
-    /** @before */
+    #[Before]
     final protected function connect(): void
     {
         if (self::$sharedConnection === null) {
@@ -43,7 +47,7 @@ abstract class FunctionalTestCase extends TestCase
         $this->connection = self::$sharedConnection;
     }
 
-    /** @after */
+    #[After]
     final protected function disconnect(): void
     {
         while ($this->connection->isTransactionActive()) {
@@ -80,7 +84,7 @@ abstract class FunctionalTestCase extends TestCase
 
         try {
             $schemaManager->dropTable($name);
-        } catch (DatabaseObjectNotFoundException $e) {
+        } catch (DatabaseObjectNotFoundException) {
         }
     }
 
