@@ -1,22 +1,23 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Platforms;
 
-use Doctrine\DBAL\Platforms\AbstractPlatform;
+use Doctrine\DBAL\Exception\InvalidColumnDeclaration;
+use Doctrine\DBAL\Platforms\AbstractMySQLPlatform;
 use Doctrine\DBAL\Platforms\MySQL;
+use Doctrine\DBAL\Platforms\MySQL\CharsetMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider;
-use Doctrine\DBAL\Platforms\MySQLPlatform;
+use Doctrine\DBAL\Platforms\MySQL\DefaultTableOptions;
 use Doctrine\DBAL\Schema\Comparator;
-use Doctrine\DBAL\Schema\ForeignKeyConstraint;
-use Doctrine\DBAL\Schema\Index;
 use Doctrine\DBAL\Schema\Table;
-use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\TransactionIsolationLevel;
 use Doctrine\DBAL\Types\Types;
 
 use function array_shift;
 
-/** @extends AbstractPlatformTestCase<MySQLPlatform> */
+/** @extends AbstractPlatformTestCase<AbstractMySQLPlatform> */
 abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 {
     public function testModifyLimitQueryWithoutLimit(): void
@@ -32,7 +33,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals(
-            'CREATE TABLE Foo (Bar INT NOT NULL) DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
+            'CREATE TABLE Foo (Bar INT NOT NULL)',
             array_shift($sql),
         );
     }
@@ -40,7 +41,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     public function getGenerateTableSql(): string
     {
         return 'CREATE TABLE test (id INT AUTO_INCREMENT NOT NULL, test VARCHAR(255) DEFAULT NULL, '
-            . 'PRIMARY KEY(id)) DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB';
+            . 'PRIMARY KEY(id))';
     }
 
     /** @return string[] */
@@ -48,16 +49,13 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     {
         return [
             'CREATE TABLE test (foo VARCHAR(255) DEFAULT NULL, bar VARCHAR(255) DEFAULT NULL, '
-                . 'UNIQUE INDEX UNIQ_D87F7E0C8C73652176FF8CAA (foo, bar))'
-                . ' DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
+                . 'UNIQUE INDEX UNIQ_D87F7E0C8C73652176FF8CAA (foo, bar))',
         ];
     }
 
     public function testGeneratesSqlSnippets(): void
     {
         self::assertEquals('RLIKE', $this->platform->getRegexpExpression());
-        self::assertEquals('`', $this->platform->getIdentifierQuoteCharacter());
-
         self::assertEquals(
             'CONCAT(column1, column2, column3)',
             $this->platform->getConcatExpression('column1', 'column2', 'column3'),
@@ -111,29 +109,6 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         );
     }
 
-    public function testGeneratesTypeDeclarationForStrings(): void
-    {
-        self::assertEquals(
-            'CHAR(10)',
-            $this->platform->getStringTypeDeclarationSQL(
-                ['length' => 10, 'fixed' => true],
-            ),
-        );
-        self::assertEquals(
-            'VARCHAR(50)',
-            $this->platform->getStringTypeDeclarationSQL(['length' => 50]),
-        );
-        self::assertEquals(
-            'VARCHAR(255)',
-            $this->platform->getStringTypeDeclarationSQL([]),
-        );
-    }
-
-    public function testPrefersIdentityColumns(): void
-    {
-        self::assertTrue($this->platform->prefersIdentityColumns());
-    }
-
     public function testSupportsIdentityColumns(): void
     {
         self::assertTrue($this->platform->supportsIdentityColumns());
@@ -159,21 +134,20 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         return 'ALTER TABLE test ADD FOREIGN KEY (fk_name_id) REFERENCES other_table (id)';
     }
 
-    /** @dataProvider comparatorProvider */
-    public function testUniquePrimaryKey(Comparator $comparator): void
+    public function testUniquePrimaryKey(): void
     {
         $keyTable = new Table('foo');
         $keyTable->addColumn('bar', Types::INTEGER);
-        $keyTable->addColumn('baz', Types::STRING);
+        $keyTable->addColumn('baz', Types::STRING, ['length' => 32]);
         $keyTable->setPrimaryKey(['bar']);
         $keyTable->addUniqueIndex(['baz']);
 
         $oldTable = new Table('foo');
         $oldTable->addColumn('bar', Types::INTEGER);
-        $oldTable->addColumn('baz', Types::STRING);
+        $oldTable->addColumn('baz', Types::STRING, ['length' => 32]);
 
-        $diff = $comparator->diffTable($oldTable, $keyTable);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($oldTable, $keyTable);
 
         $sql = $this->platform->getAlterTableSQL($diff);
 
@@ -202,45 +176,11 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         self::assertEquals('DATETIME', $this->platform->getDateTimeTypeDeclarationSQL([]));
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function getCreateTableColumnCommentsSQL(): array
-    {
-        return [
-            "CREATE TABLE test (id INT NOT NULL COMMENT 'This is a comment', "
-                . 'PRIMARY KEY(id)) DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
-        ];
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function getAlterTableColumnCommentsSQL(): array
-    {
-        return [
-            "ALTER TABLE mytable ADD quota INT NOT NULL COMMENT 'A comment', "
-                . 'CHANGE foo foo VARCHAR(255) NOT NULL, '
-                . "CHANGE bar baz VARCHAR(255) NOT NULL COMMENT 'B comment'",
-        ];
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function getCreateTableColumnTypeCommentsSQL(): array
-    {
-        return [
-            "CREATE TABLE test (id INT NOT NULL, data LONGTEXT NOT NULL COMMENT '(DC2Type:array)', "
-                . 'PRIMARY KEY(id)) DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
-        ];
-    }
-
     /** @return string[] */
     protected function getQuotedColumnInPrimaryKeySQL(): array
     {
         return ['CREATE TABLE `quoted` (`create` VARCHAR(255) NOT NULL, '
-                . 'PRIMARY KEY(`create`)) DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
+                . 'PRIMARY KEY(`create`))',
         ];
     }
 
@@ -249,8 +189,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     {
         return [
             'CREATE TABLE `quoted` (`create` VARCHAR(255) NOT NULL, '
-                . 'INDEX IDX_22660D028FD6E0FB (`create`)) '
-                . 'DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
+                . 'INDEX IDX_22660D028FD6E0FB (`create`))',
         ];
     }
 
@@ -259,7 +198,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     {
         return [
             'CREATE TABLE test (column1 VARCHAR(255) NOT NULL, '
-                . 'INDEX `key` (column1)) DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
+                . 'INDEX `key` (column1))',
         ];
     }
 
@@ -268,8 +207,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     {
         return [
             'CREATE TABLE `quoted` (`create` VARCHAR(255) NOT NULL, foo VARCHAR(255) NOT NULL, '
-                . '`bar` VARCHAR(255) NOT NULL, INDEX IDX_22660D028FD6E0FB8C736521D79164E3 (`create`, foo, `bar`)) '
-                . 'DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
+                . '`bar` VARCHAR(255) NOT NULL, INDEX IDX_22660D028FD6E0FB8C736521D79164E3 (`create`, foo, `bar`))',
             'ALTER TABLE `quoted` ADD CONSTRAINT FK_WITH_RESERVED_KEYWORD FOREIGN KEY (`create`, foo, `bar`)'
                 . ' REFERENCES `foreign` (`create`, bar, `foo-bar`)',
             'ALTER TABLE `quoted` ADD CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD FOREIGN KEY (`create`, foo, `bar`)'
@@ -294,7 +232,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
             [
                 'CREATE TABLE fulltext_table (text LONGTEXT NOT NULL, '
                 . 'FULLTEXT INDEX fulltext_text (text)) '
-                . 'DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = MyISAM',
+                . 'ENGINE = MyISAM',
             ],
             $sql,
         );
@@ -314,7 +252,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         self::assertEquals(
             [
                 'CREATE TABLE spatial_table (point LONGTEXT NOT NULL, SPATIAL INDEX spatial_text (point)) '
-                . 'DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = MyISAM',
+                . 'ENGINE = MyISAM',
             ],
             $sql,
         );
@@ -344,8 +282,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         self::assertEquals('LONGBLOB', $this->platform->getBlobTypeDeclarationSQL([]));
     }
 
-    /** @dataProvider comparatorProvider */
-    public function testAlterTableAddPrimaryKey(Comparator $comparator): void
+    public function testAlterTableAddPrimaryKey(): void
     {
         $table = new Table('alter_table_add_pk');
         $table->addColumn('id', Types::INTEGER);
@@ -357,8 +294,8 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         $diffTable->dropIndex('idx_id');
         $diffTable->setPrimaryKey(['id']);
 
-        $diff = $comparator->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($table, $diffTable);
 
         self::assertEquals(
             ['DROP INDEX idx_id ON alter_table_add_pk', 'ALTER TABLE alter_table_add_pk ADD PRIMARY KEY (id)'],
@@ -366,8 +303,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         );
     }
 
-    /** @dataProvider comparatorProvider */
-    public function testAlterPrimaryKeyWithAutoincrementColumn(Comparator $comparator): void
+    public function testAlterPrimaryKeyWithAutoincrementColumn(): void
     {
         $table = new Table('alter_primary_key');
         $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
@@ -379,8 +315,8 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         $diffTable->dropPrimaryKey();
         $diffTable->setPrimaryKey(['foo']);
 
-        $diff = $comparator->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($table, $diffTable);
 
         self::assertEquals(
             [
@@ -392,8 +328,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         );
     }
 
-    /** @dataProvider comparatorProvider */
-    public function testDropPrimaryKeyWithAutoincrementColumn(Comparator $comparator): void
+    public function testDropPrimaryKeyWithAutoincrementColumn(): void
     {
         $table = new Table('drop_primary_key');
         $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
@@ -405,8 +340,8 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 
         $diffTable->dropPrimaryKey();
 
-        $diff = $comparator->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($table, $diffTable);
 
         self::assertEquals(
             [
@@ -417,10 +352,8 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         );
     }
 
-    /** @dataProvider comparatorProvider */
-    public function testDropNonAutoincrementColumnFromCompositePrimaryKeyWithAutoincrementColumn(
-        Comparator $comparator
-    ): void {
+    public function testDropNonAutoincrementColumnFromCompositePrimaryKeyWithAutoincrementColumn(): void
+    {
         $table = new Table('tbl');
         $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
         $table->addColumn('foo', Types::INTEGER);
@@ -432,8 +365,8 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         $diffTable->dropPrimaryKey();
         $diffTable->setPrimaryKey(['id']);
 
-        $diff = $comparator->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($table, $diffTable);
 
         self::assertSame(
             [
@@ -445,8 +378,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         );
     }
 
-    /** @dataProvider comparatorProvider */
-    public function testAddNonAutoincrementColumnToPrimaryKeyWithAutoincrementColumn(Comparator $comparator): void
+    public function testAddNonAutoincrementColumnToPrimaryKeyWithAutoincrementColumn(): void
     {
         $table = new Table('tbl');
         $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
@@ -459,8 +391,8 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         $diffTable->dropPrimaryKey();
         $diffTable->setPrimaryKey(['id', 'foo']);
 
-        $diff = $comparator->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($table, $diffTable);
 
         self::assertSame(
             [
@@ -472,40 +404,25 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         );
     }
 
-    /** @dataProvider comparatorProvider */
-    public function testAddAutoIncrementPrimaryKey(Comparator $comparator): void
+    public function testAddAutoIncrementPrimaryKey(): void
     {
         $keyTable = new Table('foo');
         $keyTable->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
-        $keyTable->addColumn('baz', Types::STRING);
+        $keyTable->addColumn('baz', Types::STRING, ['length' => 32]);
         $keyTable->setPrimaryKey(['id']);
 
         $oldTable = new Table('foo');
-        $oldTable->addColumn('baz', Types::STRING);
+        $oldTable->addColumn('baz', Types::STRING, ['length' => 32]);
 
-        $diff = $comparator->diffTable($oldTable, $keyTable);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($oldTable, $keyTable);
 
         $sql = $this->platform->getAlterTableSQL($diff);
 
         self::assertEquals(['ALTER TABLE foo ADD id INT AUTO_INCREMENT NOT NULL, ADD PRIMARY KEY (id)'], $sql);
     }
 
-    public function testNamedPrimaryKey(): void
-    {
-        $diff                              = new TableDiff('mytable');
-        $diff->changedIndexes['foo_index'] = new Index('foo_index', ['foo'], true, true);
-
-        $sql = $this->platform->getAlterTableSQL($diff);
-
-        self::assertEquals([
-            'DROP INDEX foo_index ON mytable',
-            'ALTER TABLE mytable ADD PRIMARY KEY (foo)',
-        ], $sql);
-    }
-
-    /** @dataProvider comparatorProvider */
-    public function testAlterPrimaryKeyWithNewColumn(Comparator $comparator): void
+    public function testAlterPrimaryKeyWithNewColumn(): void
     {
         $table = new Table('yolo');
         $table->addColumn('pkc1', Types::INTEGER);
@@ -518,8 +435,8 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         $diffTable->dropPrimaryKey();
         $diffTable->setPrimaryKey(['pkc1', 'pkc2']);
 
-        $diff = $comparator->diffTable($table, $diffTable);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($table, $diffTable);
 
         self::assertSame(
             [
@@ -540,125 +457,18 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         self::assertSame(Types::BINARY, $this->platform->getDoctrineTypeMapping('varbinary'));
     }
 
-    protected function getBinaryMaxLength(): int
+    public function testGetVariableLengthStringTypeDeclarationSQLNoLength(): void
     {
-        return 65535;
+        $this->expectException(InvalidColumnDeclaration::class);
+
+        parent::testGetVariableLengthStringTypeDeclarationSQLNoLength();
     }
 
-    public function testReturnsBinaryTypeDeclarationSQL(): void
+    public function testGetVariableLengthBinaryTypeDeclarationSQLNoLength(): void
     {
-        self::assertSame('VARBINARY(255)', $this->platform->getBinaryTypeDeclarationSQL([]));
-        self::assertSame('VARBINARY(255)', $this->platform->getBinaryTypeDeclarationSQL(['length' => 0]));
-        self::assertSame('VARBINARY(65535)', $this->platform->getBinaryTypeDeclarationSQL(['length' => 65535]));
+        $this->expectException(InvalidColumnDeclaration::class);
 
-        self::assertSame('BINARY(255)', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true]));
-        self::assertSame('BINARY(255)', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 0]));
-
-        self::assertSame('BINARY(65535)', $this->platform->getBinaryTypeDeclarationSQL([
-            'fixed' => true,
-            'length' => 65535,
-        ]));
-    }
-
-    public function testReturnsBinaryTypeLongerThanMaxDeclarationSQL(): void
-    {
-        self::assertSame('MEDIUMBLOB', $this->platform->getBinaryTypeDeclarationSQL(['length' => 65536]));
-        self::assertSame('MEDIUMBLOB', $this->platform->getBinaryTypeDeclarationSQL(['length' => 16777215]));
-        self::assertSame('LONGBLOB', $this->platform->getBinaryTypeDeclarationSQL(['length' => 16777216]));
-
-        self::assertSame('MEDIUMBLOB', $this->platform->getBinaryTypeDeclarationSQL([
-            'fixed' => true,
-            'length' => 65536,
-        ]));
-
-        self::assertSame('MEDIUMBLOB', $this->platform->getBinaryTypeDeclarationSQL([
-            'fixed' => true,
-            'length' => 16777215,
-        ]));
-
-        self::assertSame('LONGBLOB', $this->platform->getBinaryTypeDeclarationSQL([
-            'fixed' => true,
-            'length' => 16777216,
-        ]));
-    }
-
-    public function testDoesNotPropagateForeignKeyCreationForNonSupportingEngines(): void
-    {
-        $table = new Table('foreign_table');
-        $table->addColumn('id', Types::INTEGER);
-        $table->addColumn('fk_id', Types::INTEGER);
-        $table->addForeignKeyConstraint('foreign_table', ['fk_id'], ['id']);
-        $table->setPrimaryKey(['id']);
-        $table->addOption('engine', 'MyISAM');
-
-        self::assertSame(
-            [
-                'CREATE TABLE foreign_table (id INT NOT NULL, fk_id INT NOT NULL, '
-                    . 'INDEX IDX_5690FFE2A57719D0 (fk_id), PRIMARY KEY(id)) '
-                    . 'DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = MyISAM',
-            ],
-            $this->platform->getCreateTableSQL(
-                $table,
-                AbstractPlatform::CREATE_INDEXES | AbstractPlatform::CREATE_FOREIGNKEYS,
-            ),
-        );
-
-        $table = clone $table;
-        $table->addOption('engine', 'InnoDB');
-
-        self::assertSame(
-            [
-                'CREATE TABLE foreign_table (id INT NOT NULL, fk_id INT NOT NULL, '
-                    . 'INDEX IDX_5690FFE2A57719D0 (fk_id), PRIMARY KEY(id)) '
-                    . 'DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
-                'ALTER TABLE foreign_table ADD CONSTRAINT FK_5690FFE2A57719D0 FOREIGN KEY (fk_id)'
-                    . ' REFERENCES foreign_table (id)',
-            ],
-            $this->platform->getCreateTableSQL(
-                $table,
-                AbstractPlatform::CREATE_INDEXES | AbstractPlatform::CREATE_FOREIGNKEYS,
-            ),
-        );
-    }
-
-    public function testDoesNotPropagateForeignKeyAlterationForNonSupportingEngines(): void
-    {
-        $table = new Table('foreign_table');
-        $table->addColumn('id', Types::INTEGER);
-        $table->addColumn('fk_id', Types::INTEGER);
-        $table->addForeignKeyConstraint('foreign_table', ['fk_id'], ['id']);
-        $table->setPrimaryKey(['id']);
-        $table->addOption('engine', 'MyISAM');
-
-        $addedForeignKeys   = [new ForeignKeyConstraint(['fk_id'], 'foo', ['id'], 'fk_add')];
-        $changedForeignKeys = [new ForeignKeyConstraint(['fk_id'], 'bar', ['id'], 'fk_change')];
-        $removedForeignKeys = [new ForeignKeyConstraint(['fk_id'], 'baz', ['id'], 'fk_remove')];
-
-        $tableDiff                     = new TableDiff('foreign_table');
-        $tableDiff->fromTable          = $table;
-        $tableDiff->addedForeignKeys   = $addedForeignKeys;
-        $tableDiff->changedForeignKeys = $changedForeignKeys;
-        $tableDiff->removedForeignKeys = $removedForeignKeys;
-
-        self::assertEmpty($this->platform->getAlterTableSQL($tableDiff));
-
-        $table->addOption('engine', 'InnoDB');
-
-        $tableDiff                     = new TableDiff('foreign_table');
-        $tableDiff->fromTable          = $table;
-        $tableDiff->addedForeignKeys   = $addedForeignKeys;
-        $tableDiff->changedForeignKeys = $changedForeignKeys;
-        $tableDiff->removedForeignKeys = $removedForeignKeys;
-
-        self::assertSame(
-            [
-                'ALTER TABLE foreign_table DROP FOREIGN KEY fk_remove',
-                'ALTER TABLE foreign_table DROP FOREIGN KEY fk_change',
-                'ALTER TABLE foreign_table ADD CONSTRAINT fk_add FOREIGN KEY (fk_id) REFERENCES foo (id)',
-                'ALTER TABLE foreign_table ADD CONSTRAINT fk_change FOREIGN KEY (fk_id) REFERENCES bar (id)',
-            ],
-            $this->platform->getAlterTableSQL($tableDiff),
-        );
+        parent::testGetVariableLengthBinaryTypeDeclarationSQLNoLength();
     }
 
     /** @return string[] */
@@ -701,16 +511,6 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         ];
     }
 
-    protected function getQuotesDropForeignKeySQL(): string
-    {
-        return 'ALTER TABLE `table` DROP FOREIGN KEY `select`';
-    }
-
-    protected function getQuotesDropConstraintSQL(): string
-    {
-        return 'ALTER TABLE `table` DROP CONSTRAINT `select`';
-    }
-
     public function testIgnoresDifferenceInDefaultValuesForUnsupportedColumnTypes(): void
     {
         $table = new Table('text_blob_default_value');
@@ -725,56 +525,21 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
                     . 'def_text_null LONGTEXT DEFAULT NULL, '
                     . 'def_blob LONGBLOB NOT NULL, '
                     . 'def_blob_null LONGBLOB DEFAULT NULL'
-                    . ') DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
+                    . ')',
             ],
             $this->platform->getCreateTableSQL($table),
         );
 
         $diffTable = clone $table;
-        $diffTable->changeColumn('def_text', ['default' => null]);
-        $diffTable->changeColumn('def_text_null', ['default' => null]);
-        $diffTable->changeColumn('def_blob', ['default' => null]);
-        $diffTable->changeColumn('def_blob_null', ['default' => null]);
+        $diffTable->modifyColumn('def_text', ['default' => null]);
+        $diffTable->modifyColumn('def_text_null', ['default' => null]);
+        $diffTable->modifyColumn('def_blob', ['default' => null]);
+        $diffTable->modifyColumn('def_blob_null', ['default' => null]);
 
-        $comparator = new MySQL\Comparator(
-            $this->platform,
-            $this->createMock(CollationMetadataProvider::class),
-        );
+        $comparator = $this->createComparator();
 
-        self::assertFalse($comparator->diffTable($table, $diffTable));
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    protected function getQuotedAlterTableRenameColumnSQL(): array
-    {
-        return ['ALTER TABLE mytable ' .
-            "CHANGE unquoted1 unquoted INT NOT NULL COMMENT 'Unquoted 1', " .
-            "CHANGE unquoted2 `where` INT NOT NULL COMMENT 'Unquoted 2', " .
-            "CHANGE unquoted3 `foo` INT NOT NULL COMMENT 'Unquoted 3', " .
-            "CHANGE `create` reserved_keyword INT NOT NULL COMMENT 'Reserved keyword 1', " .
-            "CHANGE `table` `from` INT NOT NULL COMMENT 'Reserved keyword 2', " .
-            "CHANGE `select` `bar` INT NOT NULL COMMENT 'Reserved keyword 3', " .
-            "CHANGE quoted1 quoted INT NOT NULL COMMENT 'Quoted 1', " .
-            "CHANGE quoted2 `and` INT NOT NULL COMMENT 'Quoted 2', " .
-            "CHANGE quoted3 `baz` INT NOT NULL COMMENT 'Quoted 3'",
-        ];
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    protected function getQuotedAlterTableChangeColumnLengthSQL(): array
-    {
-        return ['ALTER TABLE mytable ' .
-            "CHANGE unquoted1 unquoted1 VARCHAR(255) NOT NULL COMMENT 'Unquoted 1', " .
-            "CHANGE unquoted2 unquoted2 VARCHAR(255) NOT NULL COMMENT 'Unquoted 2', " .
-            "CHANGE unquoted3 unquoted3 VARCHAR(255) NOT NULL COMMENT 'Unquoted 3', " .
-            "CHANGE `create` `create` VARCHAR(255) NOT NULL COMMENT 'Reserved keyword 1', " .
-            "CHANGE `table` `table` VARCHAR(255) NOT NULL COMMENT 'Reserved keyword 2', " .
-            "CHANGE `select` `select` VARCHAR(255) NOT NULL COMMENT 'Reserved keyword 3'",
-        ];
+        self::assertTrue($comparator->compareTables($table, $diffTable)->isEmpty());
+        self::assertTrue($comparator->compareTables($table, $diffTable)->isEmpty());
     }
 
     public function testReturnsGuidTypeDeclarationSQL(): void
@@ -782,14 +547,6 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         self::assertSame('CHAR(36)', $this->platform->getGuidTypeDeclarationSQL([]));
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function getAlterTableRenameColumnSQL(): array
-    {
-        return ["ALTER TABLE foo CHANGE bar baz INT DEFAULT 666 NOT NULL COMMENT 'rename test'"];
-    }
-
     /**
      * {@inheritDoc}
      */
@@ -843,14 +600,9 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
      */
     public static function getGeneratesDecimalTypeDeclarationSQL(): iterable
     {
-        return [
-            [[], 'NUMERIC(10, 0)'],
-            [['unsigned' => true], 'NUMERIC(10, 0) UNSIGNED'],
-            [['unsigned' => false], 'NUMERIC(10, 0)'],
-            [['precision' => 5], 'NUMERIC(5, 0)'],
-            [['scale' => 5], 'NUMERIC(10, 5)'],
-            [['precision' => 8, 'scale' => 2], 'NUMERIC(8, 2)'],
-        ];
+        yield [['precision' => 10, 'scale' => 8, 'unsigned' => true], 'NUMERIC(10, 8) UNSIGNED'];
+
+        yield from parent::getGeneratesDecimalTypeDeclarationSQL();
     }
 
     /**
@@ -868,20 +620,19 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         ];
     }
 
-    public function testQuotesTableNameInListTableIndexesSQL(): void
+    /**
+     * {@inheritDoc}
+     */
+    public static function getGeneratesSmallFloatDeclarationSQL(): iterable
     {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\\\'",
-            $this->platform->getListTableIndexesSQL("Foo'Bar\\", 'foo_db'),
-        );
-    }
-
-    public function testQuotesDatabaseNameInListTableIndexesSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\\\'",
-            $this->platform->getListTableIndexesSQL('foo_table', "Foo'Bar\\"),
-        );
+        return [
+            [[], 'FLOAT'],
+            [['unsigned' => true], 'FLOAT UNSIGNED'],
+            [['unsigned' => false], 'FLOAT'],
+            [['precision' => 5], 'FLOAT'],
+            [['scale' => 5], 'FLOAT'],
+            [['precision' => 4, 'scale' => 2], 'FLOAT'],
+        ];
     }
 
     public function testQuotesDatabaseNameInListViewsSQL(): void
@@ -892,50 +643,6 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         );
     }
 
-    public function testQuotesTableNameInListTableForeignKeysSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\\\'",
-            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\"),
-        );
-    }
-
-    public function testQuotesDatabaseNameInListTableForeignKeysSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\\\'",
-            $this->platform->getListTableForeignKeysSQL('foo_table', "Foo'Bar\\"),
-        );
-    }
-
-    public function testQuotesTableNameInListTableColumnsSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\\\'",
-            $this->platform->getListTableColumnsSQL("Foo'Bar\\"),
-        );
-    }
-
-    public function testQuotesDatabaseNameInListTableColumnsSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\\\'",
-            $this->platform->getListTableColumnsSQL('foo_table', "Foo'Bar\\"),
-        );
-    }
-
-    public function testListTableForeignKeysSQLEvaluatesDatabase(): void
-    {
-        $sql = $this->platform->getListTableForeignKeysSQL('foo');
-
-        self::assertStringContainsString('DATABASE()', $sql);
-
-        $sql = $this->platform->getListTableForeignKeysSQL('foo', 'bar');
-
-        self::assertStringContainsString('bar', $sql);
-        self::assertStringNotContainsString('DATABASE()', $sql);
-    }
-
     public function testColumnCharsetDeclarationSQL(): void
     {
         self::assertSame(
@@ -960,36 +667,31 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     public function testGetCreateTableSQLWithColumnCollation(): void
     {
         $table = new Table('foo');
-        $table->addColumn('no_collation', Types::STRING);
-        $table->addColumn('column_collation', Types::STRING)->setPlatformOption('collation', 'ascii_general_ci');
+        $table->addColumn('no_collation', Types::STRING, ['length' => 255]);
+        $table->addColumn('column_collation', Types::STRING, ['length' => 255])
+            ->setPlatformOption('collation', 'ascii_general_ci');
 
         self::assertSame(
             [
                 'CREATE TABLE foo (no_collation VARCHAR(255) NOT NULL, '
-                    . 'column_collation VARCHAR(255) NOT NULL COLLATE `ascii_general_ci`) '
-                    . 'DEFAULT CHARACTER SET utf8 COLLATE `utf8_unicode_ci` ENGINE = InnoDB',
+                    . 'column_collation VARCHAR(255) NOT NULL COLLATE `ascii_general_ci`)',
             ],
             $this->platform->getCreateTableSQL($table),
         );
     }
 
-    /** @return iterable<string,array{Comparator}> */
-    public static function comparatorProvider(): iterable
+    public function testQuoteIdentifier(): void
     {
-        yield 'Generic comparator' => [
-            new Comparator(),
-        ];
+        self::assertEquals('`test`.`test`', $this->platform->quoteIdentifier('test.test'));
+    }
 
-        yield 'MySQL comparator' => [
-            new MySQL\Comparator(
-                new MySQLPlatform(),
-                new class implements CollationMetadataProvider {
-                    public function getCollationCharset(string $collation): ?string
-                    {
-                        return null;
-                    }
-                },
-            ),
-        ];
+    protected function createComparator(): Comparator
+    {
+        return new MySQL\Comparator(
+            $this->platform,
+            self::createStub(CharsetMetadataProvider::class),
+            self::createStub(CollationMetadataProvider::class),
+            new DefaultTableOptions('utf8mb4', 'utf8mb4_general_ci'),
+        );
     }
 }
