@@ -1,14 +1,17 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Schema;
 
 use Doctrine\DBAL\Platforms\MySQLPlatform;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
-use Doctrine\DBAL\Platforms\SQLServer2012Platform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
+use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\Exception\UnknownColumnOption;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
 class ColumnTest extends TestCase
@@ -32,11 +35,6 @@ class ColumnTest extends TestCase
         self::assertTrue($column->hasPlatformOption('foo'));
         self::assertEquals('bar', $column->getPlatformOption('foo'));
         self::assertFalse($column->hasPlatformOption('bar'));
-
-        self::assertEquals(['bar' => 'baz'], $column->getCustomSchemaOptions());
-        self::assertTrue($column->hasCustomSchemaOption('bar'));
-        self::assertEquals('baz', $column->getCustomSchemaOption('bar'));
-        self::assertFalse($column->hasCustomSchemaOption('foo'));
     }
 
     public function testToArray(): void
@@ -53,26 +51,25 @@ class ColumnTest extends TestCase
             'unsigned' => true,
             'autoincrement' => false,
             'columnDefinition' => null,
-            'comment' => null,
+            'comment' => '',
             'foo' => 'bar',
-            'bar' => 'baz',
         ];
 
-        self::assertEquals($expected, $this->createColumn()->toArray());
+        self::assertSame($expected, $this->createColumn()->toArray());
     }
 
     public function testSettingUnknownOptionIsStillSupported(): void
     {
-        self::expectException(UnknownColumnOption::class);
-        self::expectExceptionMessage('The "unknown_option" column option is not supported.');
+        $this->expectException(UnknownColumnOption::class);
+        $this->expectExceptionMessage('The "unknown_option" column option is not supported.');
 
         new Column('foo', $this->createMock(Type::class), ['unknown_option' => 'bar']);
     }
 
     public function testOptionsShouldNotBeIgnored(): void
     {
-        self::expectException(UnknownColumnOption::class);
-        self::expectExceptionMessage('The "unknown_option" column option is not supported.');
+        $this->expectException(UnknownColumnOption::class);
+        $this->expectExceptionMessage('The "unknown_option" column option is not supported.');
 
         $col1 = new Column('bar', Type::getType(Types::INTEGER), ['unknown_option' => 'bar', 'notnull' => true]);
         self::assertTrue($col1->getNotnull());
@@ -92,7 +89,6 @@ class ColumnTest extends TestCase
             'fixed' => true,
             'default' => 'baz',
             'platformOptions' => ['foo' => 'bar'],
-            'customSchemaOptions' => ['bar' => 'baz'],
         ];
 
         $string = Type::getType(Types::STRING);
@@ -106,7 +102,7 @@ class ColumnTest extends TestCase
         $column = new Column('`bar`', $string, []);
 
         $mysqlPlatform  = new MySQLPlatform();
-        $sqlitePlatform = new SqlitePlatform();
+        $sqlitePlatform = new SQLitePlatform();
 
         self::assertEquals('bar', $column->getName());
         self::assertEquals('`bar`', $column->getQuotedName($mysqlPlatform));
@@ -114,13 +110,13 @@ class ColumnTest extends TestCase
 
         $column = new Column('[bar]', $string);
 
-        $sqlServerPlatform = new SQLServer2012Platform();
+        $sqlServerPlatform = new SQLServerPlatform();
 
         self::assertEquals('bar', $column->getName());
         self::assertEquals('[bar]', $column->getQuotedName($sqlServerPlatform));
     }
 
-    /** @dataProvider getIsQuoted */
+    #[DataProvider('getIsQuoted')]
     public function testIsQuoted(string $columnName, bool $isQuoted): void
     {
         $type   = Type::getType(Types::STRING);
@@ -143,7 +139,7 @@ class ColumnTest extends TestCase
     public function testColumnComment(): void
     {
         $column = new Column('bar', Type::getType(Types::STRING));
-        self::assertNull($column->getComment());
+        self::assertSame('', $column->getComment());
 
         $column->setComment('foo');
         self::assertEquals('foo', $column->getComment());
