@@ -1,19 +1,18 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Schema;
 
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\Index;
-use Doctrine\DBAL\Schema\Table;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
 class ForeignKeyConstraintTest extends TestCase
 {
-    /**
-     * @param string[] $indexColumns
-     *
-     * @dataProvider getIntersectsIndexColumnsData
-     */
+    /** @param string[] $indexColumns */
+    #[DataProvider('getIntersectsIndexColumnsData')]
     public function testIntersectsIndexColumns(array $indexColumns, bool $expectedResult): void
     {
         $foreignKey = new ForeignKeyConstraint(['foo', 'bar'], 'foreign_table', ['fk_foo', 'fk_bar']);
@@ -55,13 +54,11 @@ class ForeignKeyConstraintTest extends TestCase
         ];
     }
 
-    /**
-     * @param string|Table $foreignTableName
-     *
-     * @dataProvider getUnqualifiedForeignTableNameData
-     */
-    public function testGetUnqualifiedForeignTableName($foreignTableName, string $expectedUnqualifiedTableName): void
-    {
+    #[DataProvider('getUnqualifiedForeignTableNameData')]
+    public function testGetUnqualifiedForeignTableName(
+        string $foreignTableName,
+        string $expectedUnqualifiedTableName,
+    ): void {
         $foreignKey = new ForeignKeyConstraint(['foo', 'bar'], $foreignTableName, ['fk_foo', 'fk_bar']);
 
         self::assertSame($expectedUnqualifiedTableName, $foreignKey->getUnqualifiedForeignTableName());
@@ -73,8 +70,14 @@ class ForeignKeyConstraintTest extends TestCase
         return [
             ['schema.foreign_table', 'foreign_table'],
             ['foreign_table', 'foreign_table'],
-            [new Table('schema.foreign_table'), 'foreign_table'],
-            [new Table('foreign_table'), 'foreign_table'],
         ];
     }
+
+    public function testCompareRestrictAndNoActionAreTheSame(): void
+    {
+        $fk1 = new ForeignKeyConstraint(['foo'], 'bar', ['baz'], 'fk1', ['onDelete' => 'NO ACTION']);
+        $fk2 = new ForeignKeyConstraint(['foo'], 'bar', ['baz'], 'fk1', ['onDelete' => 'RESTRICT']);
+
+        self::assertSame($fk1->onDelete(), $fk2->onDelete());
+    }
 }
