@@ -1,35 +1,42 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests;
 
 use Doctrine\DBAL\Configuration;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Driver\AbstractSQLiteDriver\Middleware\EnableForeignKeys;
+use Doctrine\DBAL\Driver\Mysqli;
 use Doctrine\DBAL\Driver\OCI8\Middleware\InitializeSession;
 use Doctrine\DBAL\DriverManager;
 use Doctrine\DBAL\Exception\DatabaseObjectNotFoundException;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\DB2Platform;
 use Doctrine\DBAL\Platforms\OraclePlatform;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\DefaultSchemaManagerFactory;
+use InvalidArgumentException;
 use PHPUnit\Framework\Assert;
 
 use function array_keys;
 use function array_map;
 use function array_values;
+use function assert;
 use function extension_loaded;
 use function file_exists;
 use function implode;
 use function in_array;
 use function is_string;
+use function str_starts_with;
 use function strlen;
-use function strpos;
 use function substr;
 use function unlink;
 
 /**
  * TestUtil is a class with static utility methods used during tests.
+ *
+ * @psalm-import-type Params from DriverManager
  */
 class TestUtil
 {
@@ -57,12 +64,14 @@ class TestUtil
      */
     public static function getConnection(): Connection
     {
-        if (self::hasRequiredConnectionParams() && ! self::$initialized) {
+        $params = self::getConnectionParams();
+
+        if (empty($params['memory']) && ! self::$initialized) {
             self::initializeDatabase();
             self::$initialized = true;
         }
 
-        $params = self::getConnectionParams();
+        assert(isset($params['driver']));
 
         return DriverManager::getConnection(
             $params,
@@ -70,19 +79,23 @@ class TestUtil
         );
     }
 
-    /** @return mixed[] */
+    /** @return Params */
     public static function getConnectionParams(): array
     {
-        if (self::hasRequiredConnectionParams()) {
-            return self::getTestConnectionParameters();
+        $params = self::getTestConnectionParameters();
+
+        if (isset($params['driver'])) {
+            return $params;
         }
 
-        return self::getFallbackConnectionParams();
-    }
+        if (! extension_loaded('pdo_sqlite')) {
+            Assert::markTestSkipped('PDO SQLite extension is not loaded');
+        }
 
-    private static function hasRequiredConnectionParams(): bool
-    {
-        return isset($GLOBALS['db_driver']);
+        return [
+            'driver' => 'pdo_sqlite',
+            'memory' => true,
+        ];
     }
 
     private static function initializeDatabase(): void
@@ -95,7 +108,7 @@ class TestUtil
 
         $platform = $privConn->getDatabasePlatform();
 
-        if ($platform instanceof SqlitePlatform) {
+        if ($platform instanceof SQLitePlatform) {
             if (isset($testConnParams['path']) && file_exists($testConnParams['path'])) {
                 unlink($testConnParams['path']);
             }
@@ -110,16 +123,28 @@ class TestUtil
             $testConn->close();
         } else {
             if (! $platform instanceof OraclePlatform) {
+                if (! isset($testConnParams['dbname'])) {
+                    throw new InvalidArgumentException(
+                        'You must have a database configured in your connection.',
+                    );
+                }
+
                 $dbname = $testConnParams['dbname'];
             } else {
+                if (! isset($testConnParams['user'])) {
+                    throw new InvalidArgumentException(
+                        'You must have a user configured in your connection.',
+                    );
+                }
+
                 $dbname = $testConnParams['user'];
             }
 
-            $sm = $privConn->getSchemaManager();
+            $sm = $privConn->createSchemaManager();
 
             try {
                 $sm->dropDatabase($dbname);
-            } catch (DatabaseObjectNotFoundException $e) {
+            } catch (DatabaseObjectNotFoundException) {
             }
 
             $sm->createDatabase($dbname);
@@ -128,19 +153,6 @@ class TestUtil
         $privConn->close();
     }
 
-    /** @return mixed[] */
-    private static function getFallbackConnectionParams(): array
-    {
-        if (! extension_loaded('pdo_sqlite')) {
-            Assert::markTestSkipped('PDO SQLite extension is not loaded');
-        }
-
-        return [
-            'driver' => 'pdo_sqlite',
-            'memory' => true,
-        ];
-    }
-
     private static function createConfiguration(string $driver): Configuration
     {
         $configuration = new Configuration();
@@ -161,7 +173,7 @@ class TestUtil
         return $configuration;
     }
 
-    /** @return mixed[] */
+    /** @return Params */
     private static function getPrivilegedConnectionParameters(): array
     {
         if (isset($GLOBALS['tmpdb_driver'])) {
@@ -174,7 +186,7 @@ class TestUtil
         return $parameters;
     }
 
-    /** @return mixed[] */
+    /** @return Params */
     private static function getTestConnectionParameters(): array
     {
         return self::mapConnectionParameters($GLOBALS, 'db_');
@@ -183,7 +195,7 @@ class TestUtil
     /**
      * @param array<string,mixed> $configuration
      *
-     * @return array<string,mixed>
+     * @return Params
      */
     private static function mapConnectionParameters(array $configuration, string $prefix): array
     {
@@ -216,12 +228,22 @@ class TestUtil
             $parameters[$parameter] = $configuration[$prefix . $parameter];
         }
 
+        if (isset($parameters['port'])) {
+            $parameters['port'] = (int) $parameters['port'];
+        }
+
         foreach ($configuration as $param => $value) {
-            if (strpos($param, $prefix . 'driver_option_') !== 0) {
+            if (! str_starts_with($param, $prefix . 'driver_option_')) {
                 continue;
             }
 
-            $parameters['driverOptions'][substr($param, strlen($prefix . 'driver_option_'))] = $value;
+            $option = substr($param, strlen($prefix . 'driver_option_'));
+
+            if ($option === Mysqli\Connection::OPTION_FLAGS) {
+                $value = (int) $value;
+            }
+
+            $parameters['driverOptions'][$option] = $value;
         }
 
         return $parameters;
@@ -234,7 +256,10 @@ class TestUtil
 
     public static function isDriverOneOf(string ...$names): bool
     {
-        return in_array(self::getConnectionParams()['driver'], $names, true);
+        $params = self::getConnectionParams();
+        assert(isset($params['driver']));
+
+        return in_array($params['driver'], $names, true);
     }
 
     /**
