@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
 use DateTime;
@@ -11,13 +13,9 @@ use Doctrine\DBAL\Types\DateImmutableType;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 
-use function get_class;
-
 class DateImmutableTypeTest extends TestCase
 {
-    /** @var AbstractPlatform&MockObject */
-    private AbstractPlatform $platform;
-
+    private AbstractPlatform&MockObject $platform;
     private DateImmutableType $type;
 
     protected function setUp(): void
@@ -28,12 +26,7 @@ class DateImmutableTypeTest extends TestCase
 
     public function testFactoryCreatesCorrectType(): void
     {
-        self::assertSame(DateImmutableType::class, get_class($this->type));
-    }
-
-    public function testReturnsName(): void
-    {
-        self::assertSame('date_immutable', $this->type->getName());
+        self::assertSame(DateImmutableType::class, $this->type::class);
     }
 
     public function testReturnsBindingType(): void
@@ -103,6 +96,7 @@ class DateImmutableTypeTest extends TestCase
 
         $date = $this->type->convertToPHPValue('2016-01-01', $this->platform);
 
+        self::assertNotNull($date);
         self::assertSame('2016-01-01 00:00:00.000000', $date->format('Y-m-d H:i:s.u'));
     }
 
@@ -112,9 +106,4 @@ class DateImmutableTypeTest extends TestCase
 
         $this->type->convertToPHPValue('invalid date string', $this->platform);
     }
-
-    public function testRequiresSQLCommentHint(): void
-    {
-        self::assertTrue($this->type->requiresSQLCommentHint($this->platform));
-    }
 }
