@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
 use DateTime;
@@ -8,33 +10,23 @@ use Doctrine\DBAL\ParameterType;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\ConversionException;
 use Doctrine\DBAL\Types\DateTimeImmutableType;
-use Doctrine\DBAL\Types\Types;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 
-use function get_class;
-
 class DateTimeImmutableTypeTest extends TestCase
 {
-    /** @var AbstractPlatform&MockObject */
-    private AbstractPlatform $platform;
-
+    private AbstractPlatform&MockObject $platform;
     private DateTimeImmutableType $type;
 
     protected function setUp(): void
     {
-        $this->platform = $this->getMockBuilder(AbstractPlatform::class)->getMock();
+        $this->platform = $this->createMock(AbstractPlatform::class);
         $this->type     = new DateTimeImmutableType();
     }
 
     public function testFactoryCreatesCorrectType(): void
     {
-        self::assertSame(DateTimeImmutableType::class, get_class($this->type));
-    }
-
-    public function testReturnsName(): void
-    {
-        self::assertSame(Types::DATETIME_IMMUTABLE, $this->type->getName());
+        self::assertSame(DateTimeImmutableType::class, $this->type::class);
     }
 
     public function testReturnsBindingType(): void
@@ -44,7 +36,7 @@ class DateTimeImmutableTypeTest extends TestCase
 
     public function testConvertsDateTimeImmutableInstanceToDatabaseValue(): void
     {
-        $date = $this->getMockBuilder(DateTimeImmutable::class)->getMock();
+        $date = $this->createMock(DateTimeImmutable::class);
 
         $this->platform->expects(self::once())
             ->method('getDateTimeFormatString')
@@ -104,6 +96,7 @@ class DateTimeImmutableTypeTest extends TestCase
 
         $date = $this->type->convertToPHPValue('2016-01-01 15:58:59.123456', $this->platform);
 
+        self::assertNotNull($date);
         self::assertSame('2016-01-01 15:58:59', $date->format('Y-m-d H:i:s'));
     }
 
@@ -117,9 +110,4 @@ class DateTimeImmutableTypeTest extends TestCase
 
         $this->type->convertToPHPValue('invalid datetime string', $this->platform);
     }
-
-    public function testRequiresSQLCommentHint(): void
-    {
-        self::assertTrue($this->type->requiresSQLCommentHint($this->platform));
-    }
 }
